@@ -101,7 +101,8 @@ tar_jags_rep_summary <- function(
   resources = targets::tar_option_get("resources"),
   storage = targets::tar_option_get("storage"),
   retrieval = targets::tar_option_get("retrieval"),
-  cue = targets::tar_option_get("cue")
+  cue = targets::tar_option_get("cue"),
+  description = targets::tar_option_get("description")
 ) {
   tar_jags_rep(
     name = targets::tar_deparse_language(substitute(name)),
@@ -142,6 +143,7 @@ tar_jags_rep_summary <- function(
     resources = resources,
     storage = storage,
     retrieval = retrieval,
-    cue = cue
+    cue = cue,
+    description = description
   )
 }
